@@ -1,5 +1,5 @@
 use swc_common::{chain, Mark};
-use swc_ecma_transforms_base::resolver::resolver_with_mark;
+use swc_ecma_transforms_base::resolver;
 
 use super::{super::expr_simplifier, dead_branch_remover};
 
@@ -8,10 +8,11 @@ macro_rules! test_stmt {
         swc_ecma_transforms_testing::test_transform(
             ::swc_ecma_parser::Syntax::default(),
             |_| {
-                let top_level_mark = Mark::fresh(Mark::root());
+                let unresolved_mark = Mark::new();
+                let top_level_mark = Mark::new();
 
                 chain!(
-                    resolver_with_mark(top_level_mark),
+                    resolver(unresolved_mark, top_level_mark, false),
                     expr_simplifier(top_level_mark, Default::default()),
                     dead_branch_remover(top_level_mark)
                 )
